#!/usr/bin/env node
"use strict";
/*
 * Copyright (c) 2022 Nango, all rights reserved.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const axios_1 = __importDefault(require("axios"));
const path_1 = __importDefault(require("path"));
const program = new commander_1.Command();
let hostport = process.env['PIZZLY_HOSTPORT'] || 'http://localhost:3004';
// Test from the package rool (/packages/cli) with 'node dist/index.js'
program
    .name('pizzly')
    .description("A CLI tool to configure Pizzly.\n\n IMPORTANT: You need to set the PIZZLY_HOSTPORT environment variable if Pizzly Server doesn't run on http://localhost:3004.");
program
    .command('config:list')
    .description('List all provider configurations.')
    .action(async () => {
    let url = path_1.default.join(hostport, '/config');
    await axios_1.default
        .get(url)
        .then((res) => {
        console.log('\n\nHere is the list of provider configuraitons:\n\n');
        console.log(res.data);
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program
    .command('config:get')
    .description('Get an provider configuration.')
    .argument('<provider_config_key>', 'The unique key of the provider configuration (chosen by you upon creating this provider configuration).')
    .action(async (provider_config_key) => {
    let url = path_1.default.join(hostport, `/config/${provider_config_key}`);
    await axios_1.default
        .get(url)
        .then((res) => {
        console.log('\n\nHere is the requested provider configuration:\n\n');
        console.log(res.data);
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program
    .command('config:create')
    .description('Create an provider configuration.')
    .argument('<provider_config_key>', 'The unique key of the provider configuration (choose a friendly name, e.g. hubspot_staging).')
    .argument('<provider>', 'The provider of the 3rd-party API, must match the template keys in https://github.com/NangoHQ/Pizzly/tree/main/packages/server/templates.yaml (e.g. hubspot).')
    .argument('<oauth_client_id>', 'The OAuth Client ID obtained from the API provider.')
    .argument('<oauth_client_secret>', 'The OAuth Client Secret obtained from the API provider.')
    .argument('<oauth_scopes>', 'The OAuth Scopes obtained from the API provider (comma-separated).')
    .action(async (provider_config_key, provider, oauth_client_id, oauth_client_secret, oauth_scopes) => {
    let body = {
        provider_config_key: provider_config_key,
        provider: provider,
        oauth_client_id: oauth_client_id,
        oauth_client_secret: oauth_client_secret,
        oauth_scopes: oauth_scopes
    };
    let url = path_1.default.join(hostport, `/config`);
    await axios_1.default
        .post(url, body)
        .then((_) => {
        console.log('\n\n✅ Successfully created a new provider configuration!\n\n');
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program
    .command('config:edit')
    .description('Edit an provider configuration.')
    .argument('<provider_config_key>', 'The unique key of the provider configuration (choose a friendly name, e.g. hubspot_staging).')
    .argument('<provider>', 'The provider of the 3rd-party API, must match the template keys in https://github.com/NangoHQ/Pizzly/tree/main/packages/server/templates.yaml (e.g. hubspot).')
    .argument('<oauth_client_id>', 'The OAuth Client ID obtained from the API provider.')
    .argument('<oauth_client_secret>', 'The OAuth Client Secret obtained from the API provider.')
    .argument('<oauth_scopes>', 'The OAuth Scopes obtained from the API provider (comma-separated).')
    .action(async (provider_config_key, provider, oauth_client_id, oauth_client_secret, oauth_scopes) => {
    let body = {
        provider_config_key: provider_config_key,
        provider: provider,
        oauth_client_id: oauth_client_id,
        oauth_client_secret: oauth_client_secret,
        oauth_scopes: oauth_scopes
    };
    let url = path_1.default.join(hostport, `/config`);
    await axios_1.default
        .put(url, body)
        .then((_) => {
        console.log('\n\n✅ Successfully edited an existing provider configuration!\n\n');
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program
    .command('config:delete')
    .description('Delete an provider configuration.')
    .argument('<provider_config_key>', 'The unique key of the provider configuration (chosen by you upon creating this provider configuration).')
    .action(async (provider_config_key) => {
    let url = path_1.default.join(hostport, `/config/${provider_config_key}`);
    await axios_1.default
        .delete(url)
        .then((_) => {
        console.log('\n\n✅ Successfully a deleted provider configuration!\n\n');
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program
    .command('auth')
    .description('Get authorization credentials.')
    .argument('<connection_id>', 'The ID of the Connection.')
    .argument('<provider_config_key>', 'The unique key of the provider configuration (chosen by you upon creating this provider configuration).')
    .action(async (connection_id, provider_config_key) => {
    let url = path_1.default.join(hostport, `/connection/${connection_id}`);
    await axios_1.default
        .get(url, { params: { provider_config_key: provider_config_key } })
        .then((res) => {
        console.log('\n\nHere is the requested connection with credentials:\n\n');
        console.log(res.data.credentials);
    })
        .catch((err) => {
        var _a, _b;
        console.log(`❌ Error: ${((_b = (_a = err.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.error) || err}`);
    });
});
program.parseAsync(process.argv);
